package com.zy.bms.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zy.bms.common.io.pc.AdminIO;
import com.zy.bms.common.vo.AdminListVo;
import com.zy.bms.mapper.AdminMapper;
import com.zy.bms.model.Admin;
import com.zy.bms.utils.MD5Util;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Service;

/**
 * 管理员 Service
 *
 * @author chenyi
 * Create on 2020/4/10
 */
@Service
public class AdminService extends ServiceImpl<AdminMapper, Admin> {

    /**
     * 分页查询管理员列表
     */
    public IPage<AdminListVo> listPage(@Param("io") AdminIO io) {
        Page<AdminListVo> page = new Page<>(io.getCurrent(), io.getSize());
        return baseMapper.listPage(page, io);
    }

    /**
     * 查询用户信息
     *
     * @param content 用户名 或 密码
     */
    public Admin getByUsernameOrPhone(String content) {
        QueryWrapper<Admin> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("username", content).or().eq("phone", content);
        return baseMapper.selectOne(queryWrapper);
    }

    /**
     * 添加用户
     */
    public void saveAdmin(Admin admin) {
        admin.setPassword(MD5Util.MD5Encode(admin.getPassword()));
        admin.setStatus(1);
        save(admin);
    }

    /**
     * 更新用户状态
     *
     * @param id     主键ID
     * @param status 状态
     */
    public void updateStatus(Integer id, Integer status) {
        UpdateWrapper<Admin> updateWrapper = new UpdateWrapper<>();
        updateWrapper.set("status", status).eq("id", id);
        update(updateWrapper);
    }
}
